summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPascal Rigaux <pixel@mandriva.com>2000-06-16 12:22:52 +0000
committerPascal Rigaux <pixel@mandriva.com>2000-06-16 12:22:52 +0000
commitfdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3 (patch)
tree25a25ff0a31430b0ee06ddcd3d1e1ad680168448
parentad824ff22cc3f0e1c03cd37fd7f791312a1468d7 (diff)
downloaddrakx-backup-do-not-use-fdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3.tar
drakx-backup-do-not-use-fdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3.tar.gz
drakx-backup-do-not-use-fdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3.tar.bz2
drakx-backup-do-not-use-fdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3.tar.xz
drakx-backup-do-not-use-fdea217b2ca6af2ba7d3e1dd20ae834de21d5ce3.zip
no_comment
-rw-r--r--Makefile4
-rw-r--r--perl-install/ChangeLog5
-rw-r--r--perl-install/detect_devices.pm2
-rw-r--r--perl-install/help.pm91
-rw-r--r--perl-install/install_steps_interactive.pm10
-rw-r--r--perl-install/modules.pm8
-rw-r--r--perl-install/share/compssList4
-rwxr-xr-xperl-install/standalone/mousedrake4
-rwxr-xr-xrescue/make_rescue_img4
-rwxr-xr-xupdate_kernel2
10 files changed, 71 insertions, 63 deletions
diff --git a/Makefile b/Makefile
index 57e7c819d..abe7d176b 100644
--- a/Makefile
+++ b/Makefile
@@ -72,7 +72,7 @@ rescue: modules
network_ks.rdz pcmcia_ks.rdz: %_ks.rdz: %.rdz
-network.rdz pcmcia.rdz hd.rdz cdrom.rdz live.rdz tftp.rdz tftprd.rdz network64.rdz hd64.rdz cdrom64.rdz live64.rdz tftp64.rdz tftprd64.rdz: dirs modules
+network.rdz pcmcia.rdz hd.rdz cdrom.rdz live.rdz tftp.rdz tftprd.rdz network64.rdz hd64.rdz cdrom64.rdz live64.rdz tftp64.rdz tftprd64.rdz blank.rdz: dirs modules
./make_boot_img $@ $(@:%.rdz=%)
$(BOOT_IMG): %.img: %.rdz
@@ -104,7 +104,7 @@ upload: tar install
# lftp -c "open mandrakesoft.com; cd $(UPLOAD_DEST)/images ; mput $(ROOTDEST)/images/*.img"
# lftp -c "open mandrakesoft.com; cd $(UPLOAD_DEST)/dosutils/autoboot/mdkinst ; put $(ROOTDEST)/dosutils/autoboot/mdkinst/vmlinuz ; mput $(ROOTDEST)/dosutils/autoboot/mdkinst/initrd.*"
# lftp -c "open mandrakesoft.com; cd $(UPLOAD_DEST)/lnx4win ; lcd $(ROOTDEST)/lnx4win ; put initrd.gz vmlinuz"
- lftp -c "open mandrakesoft.com; cd $(UPLOAD_DEST_CONTRIB)/others/src ; put ../gi.tar.bz2"
+# lftp -c "open mandrakesoft.com; cd $(UPLOAD_DEST_CONTRIB)/others/src ; put ../gi.tar.bz2"
rm -f $(ROOTDEST)/Mandrake/mdkinst.tgz
rm -f /tmp/mdkinst_done
diff --git a/perl-install/ChangeLog b/perl-install/ChangeLog
index 673154de9..29675c557 100644
--- a/perl-install/ChangeLog
+++ b/perl-install/ChangeLog
@@ -1,3 +1,8 @@
+2000-06-16 Pixel <pixel@mandrakesoft.com>
+
+ * detect_devices.pm (cdroms): fix using scd0 for ide-burners when
+ already a scsi cdrom drive
+
2000-06-13 Pablo Saratxaga <pablo@mandrakesoft.com>
* pkgs.pm: added 'acon' requirement for all right-to-left languages
diff --git a/perl-install/detect_devices.pm b/perl-install/detect_devices.pm
index 98ebcd403..eb451923f 100644
--- a/perl-install/detect_devices.pm
+++ b/perl-install/detect_devices.pm
@@ -45,7 +45,7 @@ sub cdroms() {
my @l = grep { $_->{type} eq 'cdrom' } get();
if (my @l2 = getIDEBurners()) {
require modules;
- my ($nb) = modules::add_alias('scsi_hostadapter', 'ide-scsi') =~ /(\d*)/;
+ my $nb = first(modules::add_alias('scsi_hostadapter', 'ide-scsi') =~ /(\d*)/) + 1;
foreach my $b (@l2) {
log::l("getIDEBurners: $b");
my ($e) = grep { $_->{device} eq $b } @l or next;
diff --git a/perl-install/install_steps_interactive.pm b/perl-install/install_steps_interactive.pm
index 7ea888904..36a4ce526 100644
--- a/perl-install/install_steps_interactive.pm
+++ b/perl-install/install_steps_interactive.pm
@@ -120,7 +120,7 @@ sub selectInstallClass($@) {
$::expert = $c{$_[0]} eq "expert" &&
$o->ask_from_list_('',
_("Are you sure you are an expert?
-You will be allowed to make powerfull but dangerous things here."),
+You will be allowed to make powerful but dangerous things here."),
[ _("Expert"), _("Customized") ]) ne "Customized";
};
@@ -982,8 +982,12 @@ _("Enable num lock at startup") => { val => \$u->{numlock}, type => 'bool' },
!$u->{memsize} || $u->{memsize} =~ s/^(\d+)M?$/$1M/i or $o->ask_warn('', _("Give the ram size in MB")), return 1;
my %m = reverse %l; $ENV{SECURE_LEVEL} = $o->{security} = $m{$s};
$o->{useSupermount} && $o->{security} > 3 and $o->ask_warn('', _("Can't use supermount in high security level")), return 1;
- 0;
- }
+ $o->{security} == 5 and $o->ask_okcancel('',
+_("beware: IN THIS SECURITY LEVEL, ROOT LOGIN AT CONSOLE IS NOT ALLOWED!
+If you want to be root, you have to login as a user and then use \"su\".
+More generally, do not expect to use your machine for anything but as a server.
+You have been warned.")) || return;
+ 0; }
) || return;
}
diff --git a/perl-install/modules.pm b/perl-install/modules.pm
index e3d893821..28a5cd6b7 100644
--- a/perl-install/modules.pm
+++ b/perl-install/modules.pm
@@ -590,9 +590,11 @@ sub get_pcmcia_devices($$) {
symlink("/tmp/stage2/etc/pcmcia", "/etc/pcmcia") unless -e "/etc/pcmcia";
symlink("/sbin/install", "/sbin/cardmgr") unless -x "/sbin/cardmgr";
- load("pcmcia_core");
- load($pcic);
- load("ds");
+ eval {
+ load("pcmcia_core");
+ load($pcic);
+ load("ds");
+ };
#- run cardmgr in foreground while it is configuring the card.
run_program::run("cardmgr", "-f", "-m" ,"/modules");
diff --git a/perl-install/share/compssList b/perl-install/share/compssList
index 89b33883a..f6bc1818c 100644
--- a/perl-install/share/compssList
+++ b/perl-install/share/compssList
@@ -743,8 +743,8 @@ lout-doc 31 32 10
lpg 40 0 80
lpr 0 75 39
lrzsz 0 34 0
-lslk 20 49 2
-lsof 10 0 1
+lslk 20 49 54
+lsof 10 0 67
ltrace 10 0 0
lynx 42 78 84
lyx 50 0 58
diff --git a/perl-install/standalone/mousedrake b/perl-install/standalone/mousedrake
index 7ac3b927d..d854b913d 100755
--- a/perl-install/standalone/mousedrake
+++ b/perl-install/standalone/mousedrake
@@ -48,6 +48,10 @@ substInFile {
if (/^Section "Pointer"/ .. /^EndSection/) {
s|^(\s*Protocol\s+).*|$1"$mouse->{XMOUSETYPE}"|;
s|^(\s*Device\s+).*|$1"/dev/mouse"|;
+#- my $zaxis = "4 5" if $mouse->{nbuttons} > 3;
+#- $zaxis .= " 6 7" if $mouse->{nbuttons} > 5;
+#- s|^(\s*ZAxisMapping\s+).*|$1$zaxis| if $zaxis;
+#- s|^([#]\s*ZAxisMapping\s+).*|# ZAxisMapping\t\n|; }
}
} $f if -e $f && !$::testing;
substInFile {
diff --git a/rescue/make_rescue_img b/rescue/make_rescue_img
index 3de1d5ab9..ffe078992 100755
--- a/rescue/make_rescue_img
+++ b/rescue/make_rescue_img
@@ -36,7 +36,7 @@ _ "$sudo rm -rf $tmp" if -e $tmp;
_ "mkdir $tmp";
_ 'find . -name "*~" | xargs rm -f';
_ "cp -a tree/* $tmp";
-_ "find $tmp -name CVS | xargs rm -rf";
+_ "find $tmp -name 'CVS*' | xargs rm -rf";
_ "cd $tmp; mkdir -p lib tmp modules proc";
@@ -68,7 +68,7 @@ exit 0 if $ARGV[0];
$size = `du -s $tmp | cut -f1` + 2048; #- add 2MB of free space
commands::mkdir_("-p", $mnt) if !-e $mnt;
-__ "$sudo umount $rescue";
+__ "$sudo umount $rescue 2>/dev/null";
_ "dd if=/dev/zero of=$rescue bs=1k count=$size";
_ "$mke2fs $rescue";
diff --git a/update_kernel b/update_kernel
index 9a55599b8..28f959cf8 100755
--- a/update_kernel
+++ b/update_kernel
@@ -1,6 +1,6 @@
#!/bin/bash
-KERNEL_BOOT_PATH="kernel64"
+KERNEL_BOOT_PATH="kernel"
function f() {
v=`perl -Iperl-install -Mmodules -e "print qq(\\$_.o\n) foreach modules::module_of_type(\"$1\")"`
diff --git a/perl-install/help.pm b/perl-install/help.pm
index 6a17e6c1d..af8e1611a 100644
--- a/perl-install/help.pm
+++ b/perl-install/help.pm
@@ -10,7 +10,7 @@ selectKeyboard =>
__("Choose the layout corresponding to your keyboard from the list above"),
selectInstallClass =>
- __("Choose \"Install\" if there are no previous versions of Linux
+ __("Choose \"Install\" if there are no previous versions of GNU/Linux
installed, or if you wish to use multiple distributions or versions.
Choose \"Upgrade\" if you wish to update a previous version of Mandrake Linux:
@@ -20,7 +20,7 @@ or 7.0 (Air).
Select:
- - Automated (recommended): If you have never installed Linux before, choose this. NOTE:
+ - Automated (recommended): If you have never installed GNU/Linux before, choose this. NOTE:
networking will not be configured during installation, use \"LinuxConf\"
to configure it after the install completes.
@@ -67,40 +67,38 @@ following:
"),
setupSCSI =>
- __("DrakX will attempt at first to look for one or more PCI
-SCSI adapter(s). If it finds it (or them) and knows which driver(s)
-to use, it will insert it (them) automatically.
+ __("DrakX will attempt to look for PCI SCSI adapter(s).
+If DrakX finds a SCSI adapter and knows which driver to use it will
+automatically install it (or them).
+If you have no SCSI adapter, an ISA SCSI adapter, or a
+PCI SCSI adapter that DrakX doesn't recognize you will be asked if a
+SCSI adapter is present in your system. If there is no adapter present
+you can just click 'No'. If you click 'Yes' a list of drivers will be
+presented from which you can select your specific adapter.
-If your SCSI adapter is an ISA board, or is a PCI board but DrakX
-doesn't know which driver to use for this card, or if you have no
-SCSI adapters at all, you will then be prompted on whether you have
-one or not. If you have none, answer \"No\". If you have one or more,
-answer \"Yes\". A list of drivers will then pop up, from which you
-will have to select one.
+If you had to manually specify your adapter, DrakX will
+ask if you want to specify options for it. You should allow DrakX to
+probe the hardware for the options. This usually works well.
-After you have selected the driver, DrakX will ask if you
-want to specify options for it. First, try and let the driver
-probe for the hardware: it usually works fine.
-
-
-If not, do not forget the information on your hardware that you
-could get from your documentation or from Windows (if you have it
-on your system), as suggested by the installation guide. These
-are the options you will need to provide to the driver."),
+If not, you will need to provide options to the driver.
+Review the Installation Guide for hints on retrieving this
+information from Windows (if you have it on your system),
+from hardware documentation, or from the manufacturer's
+website (if you have Internet access)."),
partitionDisks =>
__("At this point, you may choose what partition(s) to use to install
your Linux-Mandrake system if they have been already defined (from a
-previous install of Linux or from another partitionning tool). In other
+previous install of GNU/Linux or from another partitioning tool). In other
cases, hard drive partitions must be defined. This operation consists of
logically dividing the computer's hard drive capacity into separate
areas for use.
If you have to create new partitions, use \"Auto allocate\" to automatically
-create partitions for Linux. You can select the disk for partitionning by
+create partitions for GNU/Linux. You can select the disk for partitioning by
clicking on \"hda\" for the first IDE drive,
\"hdb\" for the second or \"sda\" for the first SCSI drive and so on.
@@ -163,10 +161,9 @@ check what it has done, you will be presented the list of mice
above.
-If you agree with DrakX' settings, just jump to the section
-you want by clicking on it in the menu on the left. Otherwise,
-choose a mouse type in the menu which you think is the closest
-match for your mouse.
+If you agree with DrakX's settings, just click 'Ok'.
+Otherwise you may choose the mouse that more closely matches your own
+from the menu above.
In case of a serial mouse, you will also have to tell DrakX
@@ -174,7 +171,7 @@ which serial port it is connected to."),
selectSerialPort =>
__("Please select the correct port. For example, the COM1 port under MS Windows
-is named ttyS0 under Linux."),
+is named ttyS0 under GNU/Linux."),
configureNetwork =>
__("This section is dedicated to configuring a local area
@@ -216,7 +213,7 @@ configureNetworkIP =>
sure, ask your network administrator or ISP.
- - Automatic IP: If your network uses bootp or dhcp protocol, select
+ - Automatic IP: If your network uses BOOTP or DHCP protocol, select
this option. If selected, no value is needed in \"IP address\". If you are
not sure, ask your network administrator or ISP.
"),
@@ -241,7 +238,7 @@ configureTimezone =>
__("You can now select your timezone according to where you live.
-Linux manages time in GMT or \"Greenwich Mean Time\" and translates it
+GNU/Linux manages time in GMT or \"Greenwich Mean Time\" and translates it
in local time according to the time zone you have selected."),
configureServices =>
@@ -254,7 +251,7 @@ server: you will probably want not to start any services which you don't
want."),
configurePrinter =>
- __("Linux can deal with many types of printer. Each of these
+ __("GNU/Linux can deal with many types of printer. Each of these
types require a different setup. Note however that the print
spooler uses 'lp' as the default printer name; so you
must have one printer with such a name; but you can give
@@ -329,11 +326,11 @@ createBootdisk =>
__("It is strongly recommended that you answer \"Yes\" here. If you install
Microsoft Windows at a later date it will overwrite the boot sector.
Unless you have made a bootdisk as suggested, you will not be able to
-boot into Linux any more."),
+boot into GNU/Linux any more."),
setupBootloaderBeginner =>
__("You need to indicate where you wish
-to place the information required to boot to Linux.
+to place the information required to boot to GNU/Linux.
Unless you know exactly what you are doing, choose \"First sector of
@@ -345,7 +342,7 @@ setupBootloader =>
setupBootloaderAddEntry =>
__("LILO (the LInux LOader) and Grub are bootloaders: they are able to boot
-either Linux or any other operating system present on your computer.
+either GNU/Linux or any other operating system present on your computer.
Normally, these other operating systems are correctly detected and
installed. If this is not the case, you can add an entry by hand in this
screen. Be careful as to choose the correct parameters.
@@ -376,7 +373,7 @@ when booting. The following values are available:
configureX =>
__("Now it's time to configure the X Window System, which is the
-core of the Linux GUI (Graphical User Interface). For this purpose,
+core of the GNU/Linux GUI (Graphical User Interface). For this purpose,
you must configure your video card and monitor. Most of these
steps are automated, though, therefore your work may only consist
of verifying what has been done and accept the settings :)
@@ -405,15 +402,11 @@ miscellaneous =>
- Choose security level: you can choose a security level for your
system. Please refer to the manual for complete information. Basically: if
- you don't know, select \"Medium\" ; if you really want to have a secure
- machine, choose \"Paranoid\" but beware: IN THIS LEVEL, ROOT LOGIN AT
- CONSOLE IS NOT ALLOWED! If you want to be root, you have to login as a user
- and then use \"su\". More generally, do not expect to use your machine
- for anything but as a server. You have been warned.
+ you don't know, select \"Medium\".
- Precise RAM size if needed: unfortunately, in today's PC world, there is no
standard method to ask the BIOS about the amount of RAM present in your
- computer. As a consequence, Linux may fail to detect your amount of RAM
+ computer. As a consequence, GNU/Linux may fail to detect your amount of RAM
correctly. If this is the case, you can specify the correct amount of RAM
here. Note that a difference of 2 or 4 MB is normal.
@@ -442,7 +435,7 @@ the additional instructions."),
#- __("Choose the layout corresponding to your keyboard from the list above"),
#-
#-selectPath =>
#- __("Choose \"Installation\" if there are no previous versions of Linux
#-installed, or if you wish to use multiple distributions or versions.
#-
#-
@@ -452,16 +445,16 @@ the additional instructions."),
#-selectInstallClass =>
#- __("Select:
#-
#- - Beginner: If you have never installed Linux before, and wish to
#-install the distribution elected \"Product of the year\" for 1999,
#-click here.
#-
#- - Developer: If you are familiar with Linux and will be using the
#-computer primarily for software development, you will find happiness
#-here.
#-
#- - Server: If you wish to install a general purpose server, or the
#-Linux distribution elected \"Distribution/Server\" for 1999, select
#-this.
#-
#- - Expert: If you are fluent with GNU/Linux and want to perform
@@ -493,7 +486,7 @@ the additional instructions."),
#-Linux-Mandrake system."),
#-
#-#At this point, hard drive partitions must be defined. (Unless you
#-#are overwriting a previous install of Linux and have already defined
#-#your hard drive partitions as desired.) This operation consists of
#-#logically dividing the computer's hard drive capacity into separate
#-#areas for use.
@@ -582,7 +575,7 @@ the additional instructions."),
#- __("Help"),
#-
#-configurePrinter =>
#- __("Linux can deal with many types of printer. Each of these
#-types require a different setup.
#-
#-
@@ -642,12 +635,12 @@ the additional instructions."),
#-createBootdisk =>
#- __("Please, please, answer \"Yes\" here! Just for example, when you
#-reinstall Windows, it will overwrite the boot sector. Unless you have
#-made the bootdisk as suggested, you won't be able to boot into Linux
#-any more!"),
#-
#-setupBootloader =>
#- __("You need to indicate where you wish
#-to place the information required to boot to Linux.
#-
#-
#-Unless you know exactly what you are doing, choose \"First sector of
@@ -655,7 +648,7 @@ the additional instructions."),
#-
#-configureX =>
#- __("Now it's time to configure the X Window System, which is the
#-core of the Linux GUI (Graphical User Interface). For this purpose,
#-you must configure your video card and monitor. Most of these
#-steps are automated, though, therefore your work may only consist
#-of verifying what has been done and accept the settings :)
@@ -442,7 +435,7 @@ the additional instructions."),
#-
#-selectPath =>
-#- __("Choose \"Installation\" if there are no previous versions of Linux
+#- __("Choose \"Installation\" if there are no previous versions of GNU/Linux
#-installed, or if you wish to use multiple distributions or versions.
#-
@@ -452,16 +445,16 @@ the additional instructions."),
#- __("Select:
#-
-#- - Beginner: If you have never installed Linux before, and wish to
+#- - Beginner: If you have never installed GNU/Linux before, and wish to
#-install the distribution elected \"Product of the year\" for 1999,
#-click here.
@@ -452,16 +445,16 @@ the additional instructions."),
#-click here.
#-
-#- - Developer: If you are familiar with Linux and will be using the
+#- - Developer: If you are familiar with GNU/Linux and will be using the
#-computer primarily for software development, you will find happiness
#-here.
@@ -452,16 +445,16 @@ the additional instructions."),
#-
#- - Server: If you wish to install a general purpose server, or the
-#-Linux distribution elected \"Distribution/Server\" for 1999, select
+#-GNU/Linux distribution elected \"Distribution/Server\" for 1999, select
#-this.
#-
@@ -493,7 +486,7 @@ the additional instructions."),
#-
#-#At this point, hard drive partitions must be defined. (Unless you
-#-#are overwriting a previous install of Linux and have already defined
+#-#are overwriting a previous install of GNU/Linux and have already defined
#-#your hard drive partitions as desired.) This operation consists of
#-#logically dividing the computer's hard drive capacity into separate
@@ -582,7 +575,7 @@ the additional instructions."),
#-
#-configurePrinter =>
-#- __("Linux can deal with many types of printer. Each of these
+#- __("GNU/Linux can deal with many types of printer. Each of these
#-types require a different setup.
#-
@@ -642,12 +635,12 @@ the additional instructions."),
#- __("Please, please, answer \"Yes\" here! Just for example, when you
#-reinstall Windows, it will overwrite the boot sector. Unless you have
-#-made the bootdisk as suggested, you won't be able to boot into Linux
+#-made the bootdisk as suggested, you won't be able to boot into GNU/Linux
#-any more!"),
#-
@@ -642,12 +635,12 @@ the additional instructions."),
#-setupBootloader =>
#- __("You need to indicate where you wish
-#-to place the information required to boot to Linux.
+#-to place the information required to boot to GNU/Linux.
#-
#-
@@ -655,7 +648,7 @@ the additional instructions."),
#-configureX =>
#- __("Now it's time to configure the X Window System, which is the
-#-core of the Linux GUI (Graphical User Interface). For this purpose,
+#-core of the GNU/Linux GUI (Graphical User Interface). For this purpose,
#-you must configure your video card and monitor. Most of these
#-steps are automated, though, therefore your work may only consist